@@ -3,7 +3,6 @@ import jinja2
 import typing
 import json
 import lxml
-import os
 import presalytics.story.components
 import presalytics.story.outline
 import presalytics.lib.exceptions
@@ -19,7 +18,7 @@ class MatplotlibFigure(presalytics.story.components.WidgetBase):
     A `Widget` for rendering `matplotlib.pyplot.Figure` instances in stories
 
     This class acts as wrapper class for matplotlib figures, allowing their packaging into
-    `presalytics.story.outline.Widget` objects and serialization to json.  At render-time, 
+    `presalytics.story.outline.Widget` objects and serialization to json.  At render-time,
     the figure is converted to a d3.js object via the [mpld3](https://mpld3.github.io/)
     package.
 
@@ -72,7 +71,7 @@ class MatplotlibFigure(presalytics.story.components.WidgetBase):
     def deserialize(cls, outline, **kwargs):
         figure_dict = outline.data.get("figure_dict")
         kwargs.update(**outline.additional_properties)
-        return cls(None, outline.name, figure_dict=figure_dict, **outline.additional_properties)
+        return cls(None, outline.name, figure_dict=figure_dict, id=outline.id, **outline.additional_properties)
 
     def serialize(self, **kwargs):
         data = {
@@ -86,6 +85,7 @@ class MatplotlibFigure(presalytics.story.components.WidgetBase):
         )
         return presalytics.story.outline.Widget(
             name=self.name,
+            id=self.id,
             kind=self.__component_kind__,
             plugins=[plugin_obj.to_dict()],
             data=data,
@@ -98,7 +98,7 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
     A `Widget` for rendering `matplotlib.pyplot.Figure` instances in stories
 
     This class acts as wrapper class for matplotlib figures, allowing their packaging into
-    `presalytics.story.outline.Widget` objects and serialization to json.  At render-time, 
+    `presalytics.story.outline.Widget` objects and serialization to json.  At render-time,
     the figure is converted to a d3.js object via the [mpld3](https://mpld3.github.io/)
     package.
 
@@ -114,7 +114,7 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
         the name of widget.  Must be unique within `presalytics.COMPONENTS`
 
     story_id : str, optional
-        The story of thet
+        The story id
 
     Attributes
     ----------
@@ -151,18 +151,17 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
                 'approved_styles_key': 'preloaders'
             }
         }
-    ] #type: ignore
+    ]  # type: ignore
 
     def __init__(self, figure: 'Figure', name: str, *args, **kwargs):
+        self.story_id = kwargs.get("story_id", None)
         super(MatplotlibResponsiveFigure, self).__init__(figure, name, *args, **kwargs)
         self.story_host = self.get_client(delegate_login=True).story.api_client.configuration.host
 
-        
     def to_html(self):
         html = self.create_container()
         return html
 
-
     def create_container(self, **kwargs):
         """
         Wraps the Matplotlib Figure in a SVG endpoint load via `<iframe>` that
@@ -184,15 +183,14 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
         empty_parent_div.append(frame)
         return lxml.html.tostring(empty_parent_div).decode('utf-8')
 
-
     @classmethod
     def deserialize(cls, outline, **kwargs):
         figure_dict = outline.data.get("figure_dict")
         story_id = outline.data.get("story_id", None)
         kwargs.update(**outline.additional_properties)
-        return cls(None, 
+        return cls(None,
                    outline.name,
-                   story_id,
+                   story_id=story_id,
                    figure_dict=figure_dict,
                    **kwargs)
 
@@ -208,7 +206,7 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
             data=data,
             additional_properties=self.additional_properties
         )
-    
+
     def create_subdocument(self, **kwargs):
         return self.standalone_html()
 
@@ -229,7 +227,7 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
                 <script type="text/javascript">
 
                     mpld3.draw_figure("{{ figid }}", {{ figure_json }});
-            
+
                 </script>
             </body>
         </html>""")
@@ -241,4 +239,4 @@ class MatplotlibResponsiveFigure(MatplotlibFigure):
             "figid": self.figure_id,
             "figure_json": figure_json
         }
-        return SIMPLE_HTML.render(**context)
\ No newline at end of file
+        return SIMPLE_HTML.render(**context)
