@@ -1,9 +1,7 @@
 import os
 import shutil
 import lxml.html
-import webbrowser
 import logging
-import collections
 import typing
 import tempfile
 import lxml
@@ -27,8 +25,7 @@ import presalytics.story.server
 import presalytics.story.components
 import presalytics.lib.exceptions
 if typing.TYPE_CHECKING:
-    from presalytics.story.outline import StoryOutline, Page, Plugin
-    from presalytics.story.components import PageTemplateBase, ComponentBase, WidgetBase, ThemeBase
+    from presalytics.story.outline import StoryOutline, Page
 
 
 logger = logging.getLogger('presalytics.story.revealer')
@@ -36,14 +33,14 @@ logger = logging.getLogger('presalytics.story.revealer')
 
 class Revealer(presalytics.story.components.Renderer):
     """
-    Renders `presalytics.story.outline.StoryOutline` objects to 
+    Renders `presalytics.story.outline.StoryOutline` objects to
     [reveal.js](https://github.com/hakimel/reveal.js/) presentations
 
     Parameters
     ----------
     story_outline : presalytics.story.outline.StoryOutline
         The presalytics StoryOutline to be rendered and presented
-    
+
     Attributes
     -----------
     base : lxml.etree.Element
@@ -119,10 +116,10 @@ class Revealer(presalytics.story.components.Renderer):
         except Exception:
             logger.info("Revealer could not extract story_id from outline.")
         return base
-    
+
     def get_meta_tags(self, body=tuple()):
         """
-        Security Note: If supplying a body, ensure that its already been stripped of unauthorized scripts. 
+        Security Note: If supplying a body, ensure that its already been stripped of unauthorized scripts.
         """
 
         scripts = body.findall(".//script")
@@ -138,7 +135,8 @@ class Revealer(presalytics.story.components.Renderer):
         hosts = ["https://presalytics.io", "https://*.presalytics.io"]
         approved = presalytics.lib.plugins.external.ApprovedExternalLinks().attr_dict.flatten()
         approved.update(presalytics.lib.plugins.external.ApprovedExternalScripts().attr_dict.flatten())
-        approved.update(presalytics.CONFIG.get("BROWSER_API_HOST", {}))
+        browser_hosts = {k: v for (k, v) in presalytics.settings.__dict__.items() if "BROWER_API_HOST" in k and v is not None}
+        approved.update(browser_hosts)
         for _, val in approved.items():
             url = urllib.parse.urlparse(val)
             host = "{0}://{1}".format(url.scheme, url.netloc)
@@ -164,13 +162,12 @@ class Revealer(presalytics.story.components.Renderer):
                 if w.kind == 'url':
                     url = w.data.get('url')
                     host = urllib.parse.urlparse(url).netloc  # type: ignore
-                    frame_hosts.append('https://{0}'.format(host))
+                    frame_hosts.append('https://{0}'.format(host))  # type: ignore
         return frame_hosts
 
-
     def package_as_standalone(self):
         """
-        Render the story outline as a html document with only the 
+        Render the story outline as a html document with only the
         reveal.js presentation as conent
 
         Returns
@@ -258,15 +255,15 @@ class Revealer(presalytics.story.components.Renderer):
         except Exception as ex:
             logger.exception(ex)
             t, v, tb = sys.exc_info()
-            if not presalytics.CONFIG.get("DEBUG", False):
+            if not presalytics.settings.DEBUG:  # type: ignore[attr-defined]
                 page_html = presalytics.lib.exceptions.RenderExceptionHandler(ex, "page", traceback=tb).render_exception()
             else:
                 six.reraise(t, v, tb)
-        return page_html
+        return page_html  # type: ignore
 
     def present(self, files_path=None, debug=True, port=8082, host='127.0.0.1'):
         """
-        Creates and opens the rendered story in the browser.  Story files are served by 
+        Creates and opens the rendered story in the browser.  Story files are served by
         a local flask server.  Not for production use.  Press Ctrl + C to close the server.
 
         Parameters
@@ -278,14 +275,14 @@ class Revealer(presalytics.story.components.Renderer):
         debug : str
             Defaults to True.  Indicates whether the flask server should be started
             in debug mode.
-        
+
         port : str
             The network port to serve the story onto.  Defautls to 8082.
-        
+
         host : str
             The host to for the local server.  Typically either localhost or the default gateway.
             Defaults to 127.0.0.1 (localhost).
-        
+
         """
         logger.info("Building story rendering at http://{0}:{1}".format(host, port))
         if not files_path:
